Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2235)

Unified Diff: pkg/serialization/lib/src/serialization_helpers.dart

Issue 11664006: Make Map.keys/values Iterables. (Closed) Base URL: https://dart.googlecode.com/svn/experimental/lib_v2/dart
Patch Set: Add TODO that map.keys should return a Set. Created 7 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/intl/lib/date_format.dart ('k') | pkg/serialization/lib/src/serialization_rule.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/serialization/lib/src/serialization_helpers.dart
diff --git a/pkg/serialization/lib/src/serialization_helpers.dart b/pkg/serialization/lib/src/serialization_helpers.dart
index 4bb7899f3152de2b16b8e7ac783156d221fc2e25..407c6562d2b765f6c5c5553e9f6e371672b3196b 100644
--- a/pkg/serialization/lib/src/serialization_helpers.dart
+++ b/pkg/serialization/lib/src/serialization_helpers.dart
@@ -29,11 +29,11 @@ List append(Iterable a, Iterable b) {
}
/**
* Return a sorted version of [aCollection], using the default sort criterion.
* Always returns a List, regardless of the type of [aCollection].
*/
-List sorted(aCollection) {
- var result = new List.from(aCollection);
+List sorted(anIterable) {
+ var result = new List.from(anIterable);
result.sort();
return result;
}
@@ -29,11 +29,11 @@ List append(Iterable a, Iterable b) {
}
/**
- * Return a sorted version of [aCollection], using the default sort criterion.
- * Always returns a List, regardless of the type of [aCollection].
+ * Return a sorted version of [anIterable], using the default sort criterion.
+ * Always returns a List, regardless of the type of [anIterable].
*/
« no previous file with comments | « pkg/intl/lib/date_format.dart ('k') | pkg/serialization/lib/src/serialization_rule.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698